/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "Collation.h"

/**
 * \brief Constructs a collation with no values set.
 */
Collation::Collation ()
{
    variable_ = false;
}

/**
 * \brief Adds a weight/level to this collation.
 *
 * \param weight Weight/level to add.
 */
void Collation::addWeight ( uint weight )
{
    weights_.append ( weight );
}

/**
 * \brief Gets a list of the weights/levels of this collation.
 *
 * \return QList<uint> with weights/levels.
 */
QList<uint> Collation::getWeights ()
{
    return weights_;
}

/**
 * \brief Checks if collation is variable.
 *
 * \return If true, the collation is variable.
 */
bool Collation::isVariable ()
{
    return variable_;
}

/**
 * \brief Sets the collations variable attribute.
 *
 * \param variable If true, the collation is set variable.
 */
void Collation::setVariable ( bool variable )
{
    variable_ = variable;
}

/**
 * \brief Returns all weights of the collation and its variable state in a
 * string like: "[*0000.0000.0000.0000]"(variable) or "[.0000.0000.0000.0000]"
 * (not variable).
 *
 * \return The collation in a formatted String.
 */
QString Collation::toString () const
{
    QString result = "";
    result.append ( "[" );

    QString temp;
    for ( int i = 0; i < weights_.count (); i++ )
    {
        if ( variable_ && i <= 0 )
        {
            result.append ( "*" );
        } else
        {
            result.append ( "." );
        }

        temp = QString::number ( weights_[ i ], 16 );
        while ( temp.size () < 4 )
        {
            temp.prepend ( '0' );
        }
        result.append ( temp );
    }

    result.append ( "]" );
    return result.toUpper ();
}

/**
 * \brief Checks if the collation is empty.
 *
 * \return True if the collation is empty, i.e. has no weights.
 */
bool Collation::isEmpty () const
{
    return weights_.isEmpty ();
}

