/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *                                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "UCQStatusBar.h"

/**
 * \brief Sets up the GUI with the warnings action disabled.
 *
 * \param parent Pointer to the parent QWidget.
 * \param warningsDialog Pointer to the UCQWarnings-dialog to display.
 */
UCQStatusBar::UCQStatusBar ( QWidget* parent, UCQWarnings* warningsDialog ) :
    QStatusBar ( parent )
{
    // warnings sign
    warningsDialog_ = warningsDialog;
    // we need a toolbar, to paint in the back of the action
    warningsBox_ = new QToolBar ( this );

    warningsBox_->setAutoFillBackground ( true );
    QPalette pal;
    pal.setColor ( QPalette::Button, QColor ( "yellow" ) );
    warningsBox_->setPalette ( pal );
    warningsBox_->setBackgroundRole ( QPalette::NoRole );

    warningsIcon_ = new QIcon ( ":icons/dialog-warning.svg" );
    warningsIconDeactivated_
            = new QIcon ( ":icons/dialog-warning-deactivated.svg" );

    warningsAction_ = new QAction ( *warningsIconDeactivated_, "", this );
    warningsBox_->addAction ( warningsAction_ );

    warningsBox_->setMaximumHeight ( 20 );

    addPermanentWidget ( warningsBox_ );

    connect ( warningsAction_, SIGNAL ( triggered () ),
              this,            SLOT   ( on_warningsAction_triggered () ) );

    connect ( warningsDialog, SIGNAL ( newWarnings () ),
              this,           SLOT   ( newWarnings () ) );
}

/**
 * \brief Deletes the icon objects for the warnings action.
 */
UCQStatusBar::~UCQStatusBar ()
{
    delete warningsIcon_;
    delete warningsIconDeactivated_;
}

/**
 * \brief Makes the button indicate "new warnings" by changing its icon and
 *        painting it yellow.
 */
void UCQStatusBar::newWarnings ()
{
    warningsBox_->setBackgroundRole ( QPalette::Button );
    warningsAction_->setIcon ( *warningsIcon_ );
}

/**
 * \brief Makes the button indicate "no new warnings" by changing its occurence
 *        back to normal.
 */
void UCQStatusBar::on_warningsAction_triggered ()
{
    warningsAction_->setIcon ( *warningsIconDeactivated_ );
    warningsBox_->setBackgroundRole ( QPalette::NoRole );
    warningsDialog_->show ();
}
