/***************************************************************************
 *   Copyright (C) 2010 by Martin Burgemeister, Mathis Lindemann           *
 *     																	   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef LUATABLE_H_
#define LUATABLE_H_

extern "C" {
#include <lua.h>
#include <lualib.h>
#include <lauxlib.h>
}
#include "lua/Luna.h"
#include "controller/TableController.h"
#include "lua/LuaWrapper.h"
/**
 * \class LuaTable
 * \brief Wrapper class for the table model.
 *
 * This class wraps the table model methods to use them in Lua.
 * All methods that will be used in Lua have a lua_State parameter.
 * It is needed for the communication between C and Lua. All needed functions
 * have to be registered.
 *
 * \author Martin Burgemeister <Martin.Burgemeister@gmx.de>,
 *         Mathis Lindemann <MathisLindemann@gmx.net>
 * \version 1.0
 * \date 16 August 2010
 * \see TableModel
 */
class LuaTable : public LuaWrapper
{
Q_DECLARE_TR_FUNCTIONS(LuaTable)

public:
    LuaTable  ( lua_State* );
    ~LuaTable ();

    int show           ( lua_State* );
    int hide           ( lua_State* );
    int addRange       ( lua_State* );
    int hideRange      ( lua_State* );
    int addWeightRange ( lua_State* );

    int clear ( lua_State* );
    /**
     * \brief Class name for Luna (see Luna.h)
     */
    static const char className[];
    /**
     * \brief Register of the functions.
     *
     * A RegType for all function which will be used in Lua.
     */
    static const Luna<LuaTable>::RegType Register[];

private:
    /**
     * \brief Table controller object
     */
    TableController * tableControl;
};

#endif /* LUATABLE_H_ */
